| Summary: | [Performance] Rootfs generation is inefficient (license checks) | ||
|---|---|---|---|
| Product: | [Build System, Metadata & Runtime] Meta-yocto | Reporter: | Richard Purdie <richard.purdie> |
| Component: | meta-yocto | Assignee: | Beth Flanagan <elizabeth.flanagan> |
| Status: | VERIFIED FIXED | QA Contact: | |
| Severity: | normal | ||
| Priority: | Medium | CC: | elizabeth.flanagan, jiajun.xu, laurentiu.serban, poky.bs.watcher, poky.watcher, sgw, song.liu |
| Version: | 1.3 | ||
| Target Milestone: | 1.3 M1 | ||
| Hardware: | x86 | ||
| OS: | Multiple | ||
| Whiteboard: | (P1)(Covered by current QA test plan)(Merged) | ||
| OS type for building Yocto: | --- | Type of Regression: | --- |
| Verified: | Documentation change: | --- | |
|
Description
Richard Purdie
2012-05-04 13:27:50 UTC
This is going to be a rewrite of that function. I'm part way through it now. The feature could be covered by current QA performance testing. Submitted to OE-Core: http://git.yoctoproject.org/cgit/cgit.cgi/poky-contrib/commit/?h=eflanagan/license_1.3&id=d4873d2c5a3c1b82e77bd7c64334372903a265e1 The build time for core-image-sato improved to 95 minutes (previous was 110 minutes) (In reply to comment #5) > The build time for core-image-sato improved to 95 minutes (previous was 110 > minutes) do we know what the do_rootfs time was? 4 minutes 43 seconds for do_rootfs and do_build |